@@ -1,4 +1,4 @@
-if [ ! -f /etc/wgetrc ]
+if [ ! -e /etc/wgetrc ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/wgetrc /etc/wgetrc
